@@ -10,5 +10,9 @@ var ConvenienceApiClasses_8h =
     [ "sdbus::SignalSubscriber", "classsdbus_1_1SignalSubscriber.html", null ],
     [ "sdbus::SignalUnsubscriber", "classsdbus_1_1SignalUnsubscriber.html", null ],
     [ "sdbus::PropertyGetter", "classsdbus_1_1PropertyGetter.html", null ],
-    [ "sdbus::PropertySetter", "classsdbus_1_1PropertySetter.html", null ]
+    [ "sdbus::AsyncPropertyGetter", "classsdbus_1_1AsyncPropertyGetter.html", null ],
+    [ "sdbus::PropertySetter", "classsdbus_1_1PropertySetter.html", null ],
+    [ "sdbus::AsyncPropertySetter", "classsdbus_1_1AsyncPropertySetter.html", null ],
+    [ "sdbus::AllPropertiesGetter", "classsdbus_1_1AllPropertiesGetter.html", null ],
+    [ "sdbus::AsyncAllPropertiesGetter", "classsdbus_1_1AsyncAllPropertiesGetter.html", null ]
 ];
\ No newline at end of file
